@@ -1,3 +1,4 @@
+import importlib
 from pathlib import Path
 from typing import Union, Tuple
 
@@ -53,3 +54,34 @@ class FileInclude(Include):
 
         with open(path, 'r') as file:
             return path, safe_load(file)
+
+
+class ModuleInclude(Include):
+    key = 'module'
+
+    def read(self, parent: Union[Path, None]) -> Tuple[Union[Path, None], dict]:
+        path = self._find(self.value)
+        if path is None:
+            raise ValueError(f'The module or file "{self.value}" is not found')
+
+        with open(path, 'r') as file:
+            return path, safe_load(file)
+
+    @staticmethod
+    def _find(value):
+        # TODO: default file name
+        value, file = value.split(':')
+        parts = value.split('.')
+        name = ''
+        while parts:
+            if name:
+                name += '.'
+            name += parts.pop(0)
+            try:
+                module = importlib.import_module(name)
+            except ImportError:
+                continue
+
+            path = Path(module.__path__[0], *parts, file)
+            if path.exists():
+                return path
